Holds the login creadentials and the host for the db.
The data are been used to setup the url for the db connection.
For MySql: mysql://{user}:{password}@{host}
For PostgresSql: postgres://{user}:{password}@{host}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.